@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Multilogin Plugin
-  * Copyright (c) 2003-2007 Paul Lesniewski <paul@squirrelmail.org>
+  * Copyright (c) 2003-2010 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
   *
   * @package plugins
@@ -34,18 +34,12 @@ function squirrelmail_plugin_init_multilogin() {
       = 'multilogin_registerIMAPServer';
 
 
-   // unfortunately, we can only set org_title in the title
-   // bar of the browser if we use this hook - otherwise, it's
-   // unecessary
-   //
-   $squirrelmail_plugin_hooks['webmail_top']['multilogin']
-      = 'multilogin_sqoverride_config';
-
-
    // as of SM 1.5.2, this hook replaces need for patching the SM source
+   // (note that config_override is now called prefs_backend)
    //
-   $squirrelmail_plugin_hooks['config_override']['multilogin'] 
-      = 'multilogin_sqoverride_config';
+   // $squirrelmail_plugin_hooks['config_override']['multilogin'] 
+   $squirrelmail_plugin_hooks['prefs_backend']['multilogin'] 
+      = 'multilogin_pre_sqoverride_config';
 
 
    // configtest
@@ -72,14 +66,14 @@ function multilogin_info()
                        'sm_site_username' => 'pdontthink',
                     ),
                  ),
-                 'version' => '2.3.4',
+                 'version' => '2.4.1',
                  'required_sm_version' => '1.2.9',
                  'requires_configuration' => 1,
                  'summary' => 'Allows manual selection of login server on login page.',
                  'details' => 'This plugin displays a pull-down select box with IMAP server choices on the login page.  The user will be logged in using the IMAP server that is chosen.<br /><br />Any number of SquirrelMail configuration settings may be changed for each server that is offered to the user, including IMAP server details, what plugins are activated, and any other settings found in the main SquirrelMail configuration file.',
                  'required_plugins' => array(
                     'compatibility' => array(
-                       'version' => '2.0.7',
+                       'version' => '2.0.12',
                        'activate' => FALSE,
                     )
                  ),
@@ -142,11 +136,11 @@ function multilogin_insertIMAPSelection()
   * replace global SM config values with overrides
   *
   */
-function multilogin_sqoverride_config($args='')
+function multilogin_pre_sqoverride_config($args='')
 {
 
    include_once(SM_PATH . 'plugins/multilogin/functions.php');
-   multilogin_sqoverride_config_do($args);
+   multilogin_pre_sqoverride_config_do($args);
 
 }
 
